@@ -8,7 +8,7 @@ use Scalar::Util qw/looks_like_number weaken/;
 require DynaLoader;
 our @ISA = qw(DynaLoader);
 
-our $VERSION = 1.20;
+our $VERSION = 1.21;
 
 bootstrap Math::Random::MT::Auto $VERSION;
 
@@ -45,10 +45,11 @@ sub import
             no strict 'refs';
             *{"${pkg}::$sym"} = \&{"mt_$sym"};
 
-        } elsif ($sym eq 'srand'  ||
-                 $sym eq 'seed'   ||
-                 $sym eq 'state'  ||
-                 $sym eq 'warnings')
+        } elsif ($sym eq 'srand'    ||
+                 $sym eq 'seed'     ||
+                 $sym eq 'state'    ||
+                 $sym eq 'warnings' ||
+                 $sym eq 'gaussian')
         {
             no strict 'refs';
             *{"${pkg}::$sym"} = \&$sym;
@@ -265,6 +266,26 @@ sub warnings
 }
 
 
+# Gaussian probability
+sub gaussian
+{
+    # Generalize for both OO and standalone PRNGs
+    my $obj;
+    if (defined($_[0]) &&
+        (ref($_[0]) eq __PACKAGE__ || UNIVERSAL::isa($_[0], __PACKAGE__)))
+    {
+        # OO interface
+        $obj = shift;
+    } else {
+        # Standalone interface
+        $obj = \%MRMA;
+    }
+
+    return ((@_) ? X_gaussian($obj->{'PRNG'}, $_[0])
+                 : X_gaussian($obj->{'PRNG'}));
+}
+
+
 ### OO Methods ###
 
 # Create a new PRNG object, or 'clone' an existing one
@@ -619,18 +640,23 @@ Math::Random::MT::Auto - Auto-seeded Mersenne Twister PRNG
 
 =head1 SYNOPSIS
 
-  use Math::Random::MT::Auto qw/rand32 rand/,
+  use Math::Random::MT::Auto qw/rand32 rand gaussian/,
                              '/dev/urandom' => 500,
                              'random_org';
-  # Function interface
-  my $die_roll = int(rand(6)) + 1;
+
+  # Functional interface
+  my $die_roll = 1 + int(rand(6));
 
   my $coin_flip = (rand32() & 1) ? 'heads' : 'tails';
 
-  # OO interface
-  my $rand_obj = Math::Random::MT::Auto->new('SOURCE' => '/dev/random');
+  my $rand_IQ = 100 + gaussian(15);
 
-  my $rand_num = $rand_obj->rand();
+  # OO interface
+  my $prng = Math::Random::MT::Auto->new('SOURCE' => '/dev/random');
+
+  my $angle = $prng->rand(360);
+
+  my $rand_height = 69 + $prng->gaussian(3);
 
 =head1 DESCRIPTION
 
@@ -781,7 +807,8 @@ By default, this module does not automatically export any of its functions.
 If you want to use the standalone PRNG, then you should specify the
 functions you want to use when you declare the module:
 
-  use Math::Random::MT::Auto qw/rand rand32 srand seed state warnings/;
+  use Math::Random::MT::Auto
+            qw/rand rand32 gaussian srand seed state warnings/;
 
 Without the above declarations, it is still possible to use the standalone
 PRNG by accessing the functions using their full module paths, as described
@@ -789,8 +816,10 @@ below.
 
 =over
 
-=item rand()
-=item rand($num)
+=item rand
+
+ my $rn = rand();
+ my $rn = rand($num);
 
 Behaves exactly like Perl's built-in L<rand|perlfunc/"rand">, returning a
 number uniformly distributed in [0, $num).  ($num defaults to 1.)
@@ -800,7 +829,9 @@ C<Math::Random::MT::Auto::mt_rand> (note the I<mt_> prefix).  (NOTE: If you
 still need to access Perl's built-in L<rand|perlfunc/"rand"> function, you
 can do so using C<CORE::rand()>.)
 
-=item rand32()
+=item rand32
+
+  my $int = rand32();
 
 Returns a 32-bit random integer between 0 and 2^32-1 (0xFFFFFFFF)
 inclusive.  This is the fastest method for obtaining pseudo-random numbers
@@ -809,8 +840,20 @@ with this module.
 This function may also be accessed using the full path
 C<Math::Random::MT::Auto::mt_rand32> (note the I<mt_> prefix).
 
-=item srand()
-=item srand('source', ...)
+=item gaussian
+
+  my $gn = gaussian();
+  my $gn = gaussian($num);
+
+Returns floating-point random numbers from a Guassian (normal) distribution
+(i.e., numbers that fit a bell curve) distributed about 0.  If called with
+no arguments, the distribution uses a standard deviation of 1.  Otherwise,
+the supplied argument will be used for the standard deviation.
+
+=item srand
+
+  srand();
+  srand('source', ...);
 
 This (re)seeds the PRNG.  It should definitely be called when the
 L<:!auto|/"Delayed Seeding"> option is used.  Additionally, it may be
@@ -855,10 +898,12 @@ C<Math::Random::MT::Auto::srand>.  (NOTE: If you still need to access
 Perl's built-in L<srand|perlfunc/"srand"> function, you can do so using
 C<CORE::srand($seed)>.)
 
-=item seed()
-=item seed($seed)
-=item seed(@seed)
-=item seed(\@seed)
+=item seed
+
+  my $seed = seed();
+  seed($seed);
+  seed(@seed);
+  seed(\@seed);
 
 When called without arguments, this function will return an array reference
 containing the seed last sent to the PRNG.  NOTE: Changing the data in the
@@ -875,7 +920,10 @@ of random numbers based on the same seed.
 This function may also be accessed using the full path
 C<Math::Random::MT::Auto::seed>.
 
-=item state($state)
+=item state
+
+  my $state = state();
+  state($state);
 
 When called without arguments, this function returns an array reference
 containing the current state vector of the PRNG.
@@ -884,13 +932,13 @@ To reset the PRNG to a previous state, call this function with a previously
 obtained state-vector array reference.
 
   # Get the current state of the PRNG
-  my $state_vector = state();
+  my $state = state();
 
   # Run the PRNG some more
   my $rand1 = rand32();
 
   # Restore the previous state of the PRNG
-  state($state_vector);
+  state($state);
 
   # Get another random number
   my $rand2 = rand32();
@@ -908,18 +956,18 @@ In conjunction with L<Data::Dumper> and L<do(file)|perlfunc/"do">, this
 function can be used to save and then reload the state vector between
 application runs.  (See L</"EXAMPLES"> below.)
 
-=item warnings($clear)
+=item warnings
+
+  my @warnings = warnings();
+  my @warnings = warnings(1);
 
 This function returns an array containing any error messages that were
 generated while trying to acquire seed data for the standalone PRNG.  It
 can be called after the module is loaded, or after calling L</"srand"> to
 see if there where any problems getting the seed.
 
-If called with a I<true> argument, then the stored error messages will also
-be erased.
-
-  # Get any error messages, and clear them from the module
-  my @prng_warnings = warnings(1);
+If called with a I<true> argument, the stored error messages will also be
+erased.
 
 This function may also be accessed using the full path
 C<Math::Random::MT::Auto::warnings>.
@@ -948,7 +996,9 @@ PRNGs.
 
 =over
 
-=item my $prng = Math::Random::MT::Auto->new( %options );
+=item Math::Random::MT::Auto->new
+
+  my $prng = Math::Random::MT::Auto->new( %options );
 
 Creates a new PRNG.  With no options, the PRNG is seeded using the default
 sources that were determined when the module was loaded.
@@ -971,6 +1021,7 @@ PRNG using the supplied seed data.  Otherwise, the seed data is just
 copied to the new opject.
 
 =item 'SOURCE' => 'source'
+
 =item 'SOURCE' => ['source', ...]
 
 Specifies the seeding source(s) for the PRNG.  If the C<STATE> and C<SEED>
@@ -982,7 +1033,9 @@ source list may be replaced by using the C<srand> method.
 
 =back
 
-=item my $prng2 = $prng1->new( %options );
+=item $obj->new
+
+  my $prng2 = $prng1->new( %options );
 
 Creates a new PRNG, optionally using attributes from the referenced PRNG.
 
@@ -995,17 +1048,35 @@ this case.
 
 When provided, the C<SEED> and C<SOURCE> options behave as described above.
 
-=item $prng->rand($num)
+=item $obj->rand
+
+  my $rn = $prng->rand();
+  my $rn = $prng->rand($num);
 
 Behaves like Perl's built-in L<rand|perlfunc/"rand">, returning a number
 uniformly distributed in [0, $num).  ($num defaults to 1.)
 
-=item $prng->rand32()
+=item $obj->rand32
+
+  my $int = $prng->rand32();
 
 Returns a 32-bit random integer between 0 and 2^32-1 (0xFFFFFFFF)
 inclusive.
 
-=item $prng->srand('source', ...)
+=item $obj->gaussian
+
+  my $gn = $prng->gaussian();
+  my $gn = $prng->gaussian($num);
+
+Operates like the L</"gaussian"> function described above, returning
+floating-point random numbers from a Guassian (normal) distribution
+distributed about 0 and having a standard deviation of 1 (no args), or
+C<$num>.
+
+=item $obj->srand
+
+  $prng->srand();
+  $prng->srand('source', ...);
 
 Operates like the L</"srand"> function described above, reseeding the PRNG.
 
@@ -1020,7 +1091,12 @@ If called with long-integer data (single value or an array), or a reference
 to an array of long-integers, these data will be passed to the C<seed>
 method for use in reseeding the PRNG.
 
-=item $prgn->seed()
+=item $obj->seed
+
+  my $seed = $prgn->seed();
+  $prgn->seed($seed);
+  $prgn->seed(@seed);
+  $prgn->seed(\@seed);
 
 Operates like the L</"seed"> function described above, retrieving the
 PRNG's seed, or setting the PRNG to the supplied seed.
@@ -1028,23 +1104,26 @@ PRNG's seed, or setting the PRNG to the supplied seed.
 If the PRNG object was created from another PRNG object using the C<STATE>
 option, then this method may return C<undef>.
 
-=item $prgn->state($state)
+=item $obj->state
+
+  my $state = $prgn->state();
+  $prgn->state($state);
 
 Operates like the L</"state"> function described above, retrieving the
 PRNG's state, or setting the PRNG to the supplied state.
 
-=item $prng->warnings($clear)
+=item $obj->warnings
+
+  my @warnings = $prng->warnings();
+  my @warnings = $prng->warnings(1);
 
 Operates like the L</"warnings"> function described above, retrieving any
 error messages that were generated while trying to acquire seed data for
 the PRNG.  It can be called after the object is created, or after calling
 the L</"srand"> method to see if there where any problems getting the seed.
 
-If called with a I<true> argument, then the stored error messages will also
-be erased.
-
-  # Get any error messages, and clear them from the object
-  my @prng_warnings = warnings(1);
+If called with a I<true> argument, the stored error messages will also be
+erased.
 
 =back
 
@@ -1068,7 +1147,7 @@ clearly, but here's the gist:
 
 When a thread is created, any I<blessed> objects that exist will be cloned
 between the parent and child threads such that the two copies of the object
-then function indenpendent of one another.
+then function independent of one another.
 
 However, the threading model does not support sharing I<blessed> objects
 (via C<use threads::shared>) between threads such that an object appears to
@@ -1149,10 +1228,11 @@ of pseudo-random numbers.
   use Math::Random::MT::Auto qw/rand rand32 state/;
 
   my $state = state();
-  open(FH, '>/tmp/rand_state_data.tmp');
-  print(FH Data::Dumper->Dump([$state], ['state']));
-  print(FH "1;\n");
-  close(FH);
+  if (open(my $FH, '>/tmp/rand_state_data.tmp')) {
+      print($FH Data::Dumper->Dump([$state], ['state']));
+      print($FH "1;\n");
+      close($FH);
+  }
 
 =back
 
@@ -1163,16 +1243,16 @@ of pseudo-random numbers.
   use Math::Random::MT::Auto qw/rand rand32 state/;
 
   our $state;
-  do('/tmp/rand_state_data.tmp');
+  my $rc = do('/tmp/rand_state_data.tmp');
   unlink('/tmp/rand_state_data.tmp');
-  state($state);
+  if ($rc) {
+      state($state);
+  }
 
 =back
 
 =head1 DIAGNOSTICS
 
-=over
-
 This module sets a 10 second timeout for Internet connections so that if
 something goes awry when trying to get seed data from an Internet source,
 your application will not hang for an inordinate amount of time.
@@ -1186,7 +1266,8 @@ The HotBits site has a quota on the amount of data you can request in a
 source may fail to provide any data if used too often.
 
 If the module cannot acquire any seed data from the specified sources, then
-the time() and PID will be used to seed the PRNG.
+the time() and PID will be used to seed the PRNG.  Use L</"warnings"> to
+check for seed acquisition problems.
 
 It is possible to seed the PRNG with more than 624 long-integers of data
 (through the use of a seeding subroutine supplied to L</"srand">, or by
@@ -1223,18 +1304,21 @@ L<http://random.org/>
 HotBits generates random number from a radioactive decay source.
 L<http://www.fourmilab.ch/hotbits/>
 
-OpenBSD random devices.
+OpenBSD random devices:
 L<http://www.openbsd.org/cgi-bin/man.cgi?query=arandom&sektion=4&apropos=0&manpath=OpenBSD+Current&arch=>
 
-FreeBSD random devices.
+FreeBSD random devices:
 L<http://www.freebsd.org/cgi/man.cgi?query=random&sektion=4&apropos=0&manpath=FreeBSD+5.3-RELEASE+and+Ports>
 
-Man pages for F</dev/random> and F</dev/urandom> on Unix/Linux/Cygwin/Solaris.
+Man pages for F</dev/random> and F</dev/urandom> on Unix/Linux/Cygwin/Solaris:
 L<http://www.die.net/doc/linux/man/man4/random.4.html>
 
-Windows XP random data source
+Windows XP random data source:
 L<http://blogs.msdn.com/michael_howard/archive/2005/01/14/353379.aspx>
 
+Gaussian distribution function code:
+L<http://home.online.no/~pjacklam/notes/invnorm/>
+
 L<LWP::UserAgent>
 
 L<Math::Random::MT>
@@ -1247,15 +1331,16 @@ Jerry D. Hedden, S<E<lt>jdhedden AT 1979 DOT usna DOT comE<gt>>
 
 =head1 COPYRIGHT AND LICENSE
 
+- Mersenne Twister PRNG -
+
 A C-program for MT19937, with initialization improved 2002/1/26.
 Coded by Takuji Nishimura and Makoto Matsumoto, and including
 Shawn Cokus's optimizations.
 
-Copyright (C) 1997 - 2002, Makoto Matsumoto and Takuji Nishimura,
-All rights reserved.
-Copyright (C) 2005, Mutsuo Saito,
-All rights reserved.
-Copyright 2005 Jerry D. Hedden S<E<lt>jdhedden AT 1979 DOT usna DOT comE<gt>>
+ Copyright (C) 1997 - 2002, Makoto Matsumoto and Takuji Nishimura,
+  All rights reserved.
+ Copyright (C) 2005, Mutsuo Saito, All rights reserved.
+ Copyright 2005 Jerry D. Hedden S<E<lt>jdhedden AT 1979 DOT usna DOT comE<gt>>
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
@@ -1284,8 +1369,15 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-Any feedback is very welcome.
-S<E<lt>m-mat AT math DOT sci DOT hiroshima-u DOT ac DOT jpE<gt>>
-L<http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt.html>
+ Any feedback is very welcome.
+ S<E<lt>m-mat AT math DOT sci DOT hiroshima-u DOT ac DOT jpE<gt>>
+ L<http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt.html>
+
+- Gaussian Function Code -
+
+ Author: Peter J. Acklam
+ http://home.online.no/~pjacklam/notes/invnorm/
+ C implementation by V. Natarajan
+ Released to public domain
 
 =cut
